Package: psre
Type: Package
Title: Presenting Statistical Results Effectively
Version: 0.4
Authors@R: c(person("Dave", "Armstrong", role=c("aut", "cre"), email="davearmstrong.ps@gmail.com"), 
             person("Robert", "Andersen", role="aut"), 
             person("Justin", "Esarey", role="cph"), 
             person("John", "Fox", role="cph"), 
             person("Michael", "Friendly", role="cph"), 
             person("Adrian", "Bowman", role="cph"), 
             person("Adelchi", "Azzalini", role="cph"), 
             person("Dewey", "Michael", role="cph"))
Description: Includes functions and data used in the book "Presenting Statistical Results Effectively", Andersen and Armstrong (2022, ISBN: 978-1446269800).  Several functions aid in data visualization - creating compact letter displays for simple slopes, kernel density estimates with normal density overlay.  Other functions aid in post-model evaluation heatmap fit statistics for binary predictors, several variable importance measures, compact letter displays and simple-slope calculation. Finally, the package makes available the example datasets used in the book. 
biocViews:
Imports: stats, MASS, car, nortest, marginaleffects, ggplot2, boot,
        grid, cowplot, fANCOVA, dplyr, tidyr, utils, magrittr, tibble,
        sm, multcomp, rlang, ggrepel, mgcv, VizTest
Suggests: ggeffects, nnet
Depends: R (>= 3.5.0)
License: GPL (>= 2)
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-12-18 15:53:03 UTC; david
Author: Dave Armstrong [aut, cre],
  Robert Andersen [aut],
  Justin Esarey [cph],
  John Fox [cph],
  Michael Friendly [cph],
  Adrian Bowman [cph],
  Adelchi Azzalini [cph],
  Dewey Michael [cph]
Maintainer: Dave Armstrong <davearmstrong.ps@gmail.com>
Repository: CRAN
Date/Publication: 2025-12-18 17:10:02 UTC
Built: R 4.6.0; ; 2026-04-25 14:05:29 UTC; unix
