# Generated by roxygen2: do not edit by hand

S3method(cld,ss)
S3method(print,srr)
S3method(print,ss)
export(assocfun)
export(boot_imp)
export(caption)
export(dfbhist)
export(gg_hmf)
export(glmImp)
export(letter_plot)
export(linear_args)
export(loess_args)
export(lsa)
export(normBand)
export(optCL)
export(qqPoints)
export(rrPlot)
export(shuffle)
export(simple_slopes)
export(srr_imp)
export(tpb)
export(transNorm)
importFrom(MASS,mvrnorm)
importFrom(MASS,rlm)
importFrom(VizTest,make_vt_data)
importFrom(VizTest,viztest)
importFrom(boot,boot)
importFrom(boot,boot.ci)
importFrom(car,bcPower)
importFrom(car,bcnPower)
importFrom(car,powerTransform)
importFrom(car,yjPower)
importFrom(cowplot,plot_grid)
importFrom(dplyr,all_of)
importFrom(dplyr,arrange)
importFrom(dplyr,case_when)
importFrom(dplyr,filter)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,pull)
importFrom(dplyr,select)
importFrom(fANCOVA,loess.as)
importFrom(ggplot2,aes)
importFrom(ggplot2,aes_string)
importFrom(ggplot2,coord_cartesian)
importFrom(ggplot2,coord_flip)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_text)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_abline)
importFrom(ggplot2,geom_errorbarh)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_ribbon)
importFrom(ggplot2,geom_segment)
importFrom(ggplot2,geom_smooth)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggplot_build)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,theme_classic)
importFrom(ggplot2,ylab)
importFrom(ggrepel,geom_text_repel)
importFrom(grid,gpar)
importFrom(grid,rectGrob)
importFrom(grid,textGrob)
importFrom(grid,unit)
importFrom(magrittr,"%>%")
importFrom(marginaleffects,avg_predictions)
importFrom(marginaleffects,datagrid)
importFrom(mgcv,gam)
importFrom(multcomp,cld)
importFrom(nortest,ad.test)
importFrom(nortest,lillie.test)
importFrom(nortest,sf.test)
importFrom(rlang,.data)
importFrom(sm,sm.density)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,cor)
importFrom(stats,density)
importFrom(stats,dfbetas)
importFrom(stats,dnorm)
importFrom(stats,loess)
importFrom(stats,loess.control)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,na.fail)
importFrom(stats,na.omit)
importFrom(stats,optimize)
importFrom(stats,p.adjust)
importFrom(stats,p.adjust.methods)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,ppoints)
importFrom(stats,predict)
importFrom(stats,pt)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,rbinom)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,shapiro.test)
importFrom(stats,terms)
importFrom(stats,update)
importFrom(stats,vcov)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
importFrom(tidyr,separate)
importFrom(utils,combn)
importFrom(utils,getFromNamespace)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
